Package 'nimbleJSextras'

Title: Aadditional Functions and Distributions For Bayesian Inference Of Jolly-Seber Models For The NIMBLE Package
Description: More about what it does (maybe more than one line). Continuation lines should be indented.
Authors: Devin Johnson [aut, cre]
Maintainer: Devin Johnson <[email protected]>
License: CC0
Version: 0.0.9024
Built: 2026-05-25 06:22:56 UTC
Source: https://github.com/dsjohnson/nimbleJSextras

Help Index


—————————————————————————– Binomial addition —————————————————————————–

Description

—————————————————————————– Binomial addition —————————————————————————–

Usage

dJS_binom(x, init, prob, size, probTrans, pstar, weight = 1, len = 0, log = 0)

—————————————————————————– Poission observations —————————————————————————–

Description

—————————————————————————– Poission observations —————————————————————————–

Usage

dJS_pois(x, init, rate, probTrans, pstar, weight = 1, len = 0, log = 0)

Create liest arguments for a random walk of order 'p'.to be used in the 'dcar_normal' distribution

Description

This function calculates the entries for a precision matrix for a random walk of order 'p'.

Usage

make_nimble_icar(n, p = 1)

Arguments

n

The length of the RW(p) process. The length must be greater than or equal to 2*p.

p

The order of the random walk process.

Value

A list with elements: 'adj', 'weights', and 'num' for use with the 'dcar_normal' distribution in 'nimble' models

References

H. Rue and L. Held (2005) Gaussian Markov Random Fields. Chapman & Hall/CRC. 263 pp.