| Title: | Aadditional Functions and Distributions For Bayesian Inference Of Jolly-Seber Models For The NIMBLE Package |
|---|---|
| Description: | More about what it does (maybe more than one line). Continuation lines should be indented. |
| Authors: | Devin Johnson [aut, cre] |
| Maintainer: | Devin Johnson <[email protected]> |
| License: | CC0 |
| Version: | 0.0.9024 |
| Built: | 2026-05-25 06:22:56 UTC |
| Source: | https://github.com/dsjohnson/nimbleJSextras |
—————————————————————————– Binomial addition —————————————————————————–
dJS_binom(x, init, prob, size, probTrans, pstar, weight = 1, len = 0, log = 0)dJS_binom(x, init, prob, size, probTrans, pstar, weight = 1, len = 0, log = 0)
—————————————————————————– Poission observations —————————————————————————–
dJS_pois(x, init, rate, probTrans, pstar, weight = 1, len = 0, log = 0)dJS_pois(x, init, rate, probTrans, pstar, weight = 1, len = 0, log = 0)
This function calculates the entries for a precision matrix for a random walk of order 'p'.
make_nimble_icar(n, p = 1)make_nimble_icar(n, p = 1)
n |
The length of the RW(p) process. The length must be greater than or equal to |
p |
The order of the random walk process. |
A list with elements: 'adj', 'weights', and 'num' for use with the 'dcar_normal' distribution in 'nimble' models
H. Rue and L. Held (2005) Gaussian Markov Random Fields. Chapman & Hall/CRC. 263 pp.